<?php
if ( ! function_exists('blankslate_setup') ) :

function blankslate_setup() {
  load_theme_textdomain( 'blankslate', get_template_directory() . '/languages');
  add_theme_support('title-tag');
  add_theme_support('automatic-feed-links');
  add_theme_support('post-thumbnails');
  global $content_width;
  if ( ! isset( $content_width ) ) $content_width = 640;
  register_nav_menus(
    array( 'main-menu' => __( 'Main Menu', 'blankslate' ) )
  );
}

endif;
add_action('after_setup_theme', 'blankslate_setup');

add_action( 'widgets_init', 'blankslate_widgets_init' );

function blankslate_widgets_init(){
	register_sidebar(
		array(
			'name'          => 'Footer Text Area',
			'id'            => 'footer-widget-area',
			'description'   => 'Copyright text',
			'before_widget' => '<div id="%1$s" class="copyright widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => 'Newsletter Area',
			'id'            => 'newsletter-area',
			'description'   => 'Place for newsletter widget',
			'before_title'  => '',
			'after_title'   => '',
		)
	);
}

function wpdocs_custom_excerpt_length( $length ) {
  return 50;
}
add_filter( 'excerpt_length', 'wpdocs_custom_excerpt_length', 999 );

function wpdocs_excerpt_more( $more ) {
  return '...';
}
add_filter( 'excerpt_more', 'wpdocs_excerpt_more' );

function unregister_email_widget() {
	unregister_widget( 'es_widget_register' );
}
add_action( 'widgets_init', 'unregister_email_widget', 20 );

function shorten_title( $title ) {
	if (strlen($title) < 375) {
		return $title;
	}
	$newTitle = substr( $title, 0, 75 );
	$title_arr = explode(" ", $newTitle);
	array_pop($title_arr);
	$refactoredTitle = implode(" ", $title_arr);
	return $refactoredTitle . " &hellip;"; // Append the elipsis to the text (...)
}
add_filter( 'the_title', 'shorten_title', 10, 1 );


add_action( 'wp_enqueue_scripts', function () {
	wp_enqueue_script( 'imagesloaded', '//cdnjs.cloudflare.com/ajax/libs/jquery.imagesloaded/4.1.3/imagesloaded.min.js', [ 'jquery' ], null, true );
	wp_enqueue_script( 'infinitescroll', '//cdnjs.cloudflare.com/ajax/libs/jquery-infinitescroll/2.1.0/jquery.infinitescroll.min.js', [ 'jquery' ], null, true );
}, 100 );


add_filter('mce_buttons_2', 'wpse3882_mce_buttons_2');
function wpse3882_mce_buttons_2($buttons)
{
    array_unshift($buttons, 'styleselect');
    return $buttons;
}

add_filter('tiny_mce_before_init', 'wpse3882_tiny_mce_before_init');
function wpse3882_tiny_mce_before_init($settings)
{
	$settings['theme_advanced_blockformats'] = 'a,p,h1,h2,h3,h4';
	
    $style_formats = array(
		array('title' => 'Remove Styling','block' => 'p', 'attributes' => array('class' => '')),
		array('title' => 'Article Description', 'block' => 'p', 'attributes' => array('class' => ''), 'classes' => 'blog-article__description new-content'),
		array('title' => 'h2 Title', 'block' => 'h2', 'attributes' => array('class' => ''), 'classes' => 'blog-article__title_secondary new-content'),
		array('title' => 'h3 Title', 'block' => 'h3', 'attributes' => array('class' => ''), 'classes' => 'blog-article__title_tertiary new-content'),
		array('title' => 'Body', 'block' => 'p', 'attributes' => array('class' => ''), 'classes' => 'blog-article__text new-content'),
		array('title' => 'Quote (with author name only)', 'attributes' => array('class' => ''), 'block' => 'blockquote', 'classes' => 'blog-article__blockquote-lvl-2 new-content'),
		array('title' => 'Author name (with quote only)', 'attributes' => array('class' => ''), 'block' => 'p', 'classes' => 'blog-article__quote-author new-content'),
		array('title' => 'Single photo', 'block' => 'p', 'attributes' => array('class' => ''), 'classes' => 'blog-article__photo-wrap new-content'),
		array('title' => 'Gallery', 'block' => 'div', 'attributes' => array('class' => ''), 'exact' => 'true', 'classes' => 'blog-slider blog-article__slider new-content'),
		array('title' => 'Bulleted list', 'selector' => 'ul', 'attributes' => array('class' => ''), 'classes' => 'blog-article__unordered-list new-content', 'wrapper' => true),
		array('title' => 'Check Mark list2', 'selector' => 'ul', 'attributes' => array('class' => ''), 'classes' => 'blog-article__check-mark-list new-content', 'wrapper' => true),
		array('title' => 'Numbered list', 'selector' => 'ol', 'attributes' => array('class' => ''), 'classes' => 'blog-article__ordered-list new-content', 'wrapper' => true)
		// array('title' => 'Highlight', 'block' => 'blockquote', 'classes' => 'blog-article__blockquote-lvl-1'),
	);
	
    // Before 3.1 you needed a special trick to send this array to the configuration.
    // See this post history for previous versions.
    $settings['style_formats'] = json_encode( $style_formats );
	
    return $settings;
}

function custom_editor_styles () { 
	add_editor_style ('css/style.css');
} 
add_action ('init', 'custom_editor_styles');

  function TinyMCE_text_paste_settings( $init ) {
  	$init['paste_auto_cleanup_on_paste'] = true;
  	$init['paste_as_text'] = true;

  	return $init;
  }
  add_filter( 'tiny_mce_before_init', 'TinyMCE_text_paste_settings' );


function gavickpro_add_my_tc_button() {
    global $typenow;
    // check user permissions
    if ( !current_user_can('edit_posts') && !current_user_can('edit_pages') ) {
    return;
    }
    // verify the post type
    if( ! in_array( $typenow, array( 'post', 'page' ) ) )
        return;
    // check if WYSIWYG is enabled
    if ( get_user_option('rich_editing') == 'true') {
        add_filter("mce_external_plugins", "gavickpro_add_tinymce_plugin");
        add_filter('mce_buttons', 'gavickpro_register_my_tc_button');
    }
}
add_action('admin_head', 'gavickpro_add_my_tc_button');

function gavickpro_add_tinymce_plugin($plugin_array) {
    $plugin_array['gavickpro_tc_button'] = get_template_directory_uri().'/js/tinymce-buttons.js';
    return $plugin_array;
}

function gavickpro_register_my_tc_button($buttons) {
   array_push($buttons, "gavickpro_tc_button");
   return $buttons;
}

  function TinyMCE_test( $init ) {
	$init['valid_children'] = '+a[h6]';
	$init['setup'] = 'function (ed) {
		ed.on("keydown", function(e) {
			if (e.keyCode == 8 || e.keyCode == 46) {
				try {
					var elem = ed.selection.getNode();
					if (elem.classList.contains("blog-article__contact-url-content")) {
						if (elem.textContent.length === 1) {
							e.preventDefault();
							return false;
						}
					}
				} catch (e) {}
			}
		});
    }';
	


	  return $init;
  }
  add_filter( 'tiny_mce_before_init', 'TinyMCE_test' );

  remove_filter ('the_content', 'wpautop');